@@ -42,7 +42,7 @@ import redis
 if list(map(int, redis.__version__.split('.'))) < [2, 4, 12]:
     raise Exception("Upgrade your Redis client to version 2.4.12 or later")
 
-VERSION = '0.25.2'
+VERSION = '0.25.6'
 
 RPQUEUE_CONFIGS = {}
 
@@ -66,6 +66,9 @@ def new_rpqueue(name, pfix=None):
     # :P
 
     # copy the original rpqueue out, that's our registry
+    
+    # imp.load_module('rpqueue_alternate', *imp.find_module('rpqueue'))
+    
     root = sys.modules[__name__]
     configs = root.RPQUEUE_CONFIGS
     if name in configs:
@@ -142,6 +145,8 @@ log_handler = logging.root
 SUCCESS_LOG_LEVEL = 'debug'
 AFTER_FORK = None
 
+CURRENT_TASK = threading.local()
+
 def _assert(condition, message, *args):
     if not condition:
         raise ValueError(message%args)
@@ -548,7 +553,9 @@ class _ExecutingTask(object):
     def __call__(self, *args, **kwargs):
         self.args = args
         self.kwargs = kwargs
+        CURRENT_TASK.task = self
         result = self.task.function(*args, **kwargs)
+        del CURRENT_TASK.task
         if self.task.save_results > 0:
             get_connection().setex(
                 RESULT_KEY + self.taskid,
